@@ -1,3 +1,4 @@
+import functools
 import json
 import os
 import sys
@@ -6,8 +7,10 @@ from enum import Enum
 
 import asyncclick as click
 from asyncclick import Context, UsageError
-from tortoise import ConfigurationError, Tortoise, generate_schema_for_client
+from tortoise import Tortoise, generate_schema_for_client
+from tortoise.exceptions import OperationalError
 from tortoise.transactions import in_transaction
+from tortoise.utils import get_schema_sql
 
 from aerich.migrate import Migrate
 from aerich.utils import get_app_connection, get_app_connection_name, get_tortoise_config
@@ -25,12 +28,22 @@ class Color(str, Enum):
 parser = ConfigParser()
 
 
+def close_db(func):
+    @functools.wraps(func)
+    async def close_db_inner(*args, **kwargs):
+        result = await func(*args, **kwargs)
+        await Tortoise.close_connections()
+        return result
+
+    return close_db_inner
+
+
 @click.group(context_settings={"help_option_names": ["-h", "--help"]})
-@click.version_option(__version__)
+@click.version_option(__version__, "-V", "--version")
 @click.option(
     "-c", "--config", default="aerich.ini", show_default=True, help="Config file.",
 )
-@click.option("--app", default="models", show_default=True, help="Tortoise-ORM app name.")
+@click.option("--app", required=False, help="Tortoise-ORM app name.")
 @click.option(
     "-n",
     "--name",
@@ -43,7 +56,6 @@ async def cli(ctx: Context, config, app, name):
     ctx.ensure_object(dict)
     ctx.obj["config_file"] = config
     ctx.obj["name"] = name
-    ctx.obj["app"] = app
 
     invoked_subcommand = ctx.invoked_subcommand
     if invoked_subcommand != "init":
@@ -55,20 +67,21 @@ async def cli(ctx: Context, config, app, name):
         tortoise_orm = parser[name]["tortoise_orm"]
 
         tortoise_config = get_tortoise_config(ctx, tortoise_orm)
-
+        app = app or list(tortoise_config.get("apps").keys())[0]
+        if "aerich.models" not in tortoise_config.get("apps").get(app).get("models"):
+            raise UsageError("Check your tortoise config and add aerich.models to it.", ctx=ctx)
         ctx.obj["config"] = tortoise_config
         ctx.obj["location"] = location
+        ctx.obj["app"] = app
 
         if invoked_subcommand != "init-db":
-            try:
-                await Migrate.init_with_old_models(tortoise_config, app, location)
-            except ConfigurationError:
-                raise UsageError(ctx=ctx, message="You must exec init-db first")
+            await Migrate.init_with_old_models(tortoise_config, app, location)
 
 
 @cli.command(help="Generate migrate changes file.")
 @click.option("--name", default="update", show_default=True, help="Migrate name.")
 @click.pass_context
+@close_db
 async def migrate(ctx: Context, name):
     config = ctx.obj["config"]
     location = ctx.obj["location"]
@@ -83,20 +96,25 @@ async def migrate(ctx: Context, name):
 
 @cli.command(help="Upgrade to latest version.")
 @click.pass_context
+@close_db
 async def upgrade(ctx: Context):
     config = ctx.obj["config"]
     app = ctx.obj["app"]
     migrated = False
     for version in Migrate.get_all_version_files():
-        if not await Aerich.exists(version=version, app=app):
+        try:
+            exists = await Aerich.exists(version=version, app=app)
+        except OperationalError:
+            exists = False
+        if not exists:
             async with in_transaction(get_app_connection_name(config, app)) as conn:
                 file_path = os.path.join(Migrate.migrate_location, version)
-                with open(file_path, "r") as f:
+                with open(file_path, "r", encoding="utf-8") as f:
                     content = json.load(f)
                     upgrade_query_list = content.get("upgrade")
                     for upgrade_query in upgrade_query_list:
-                        await conn.execute_query(upgrade_query)
-            await Aerich.create(version=version, app=app)
+                        await conn.execute_script(upgrade_query)
+                await Aerich.create(version=version, app=app)
             click.secho(f"Success upgrade {version}", fg=Color.green)
             migrated = True
     if not migrated:
@@ -105,6 +123,7 @@ async def upgrade(ctx: Context):
 
 @cli.command(help="Downgrade to previous version.")
 @click.pass_context
+@close_db
 async def downgrade(ctx: Context):
     app = ctx.obj["app"]
     config = ctx.obj["config"]
@@ -114,9 +133,11 @@ async def downgrade(ctx: Context):
     file = last_version.version
     async with in_transaction(get_app_connection_name(config, app)) as conn:
         file_path = os.path.join(Migrate.migrate_location, file)
-        with open(file_path, "r") as f:
+        with open(file_path, "r", encoding="utf-8") as f:
             content = json.load(f)
             downgrade_query_list = content.get("downgrade")
+            if not downgrade_query_list:
+                return click.secho("No downgrade item found", fg=Color.yellow)
             for downgrade_query in downgrade_query_list:
                 await conn.execute_query(downgrade_query)
             await last_version.delete()
@@ -125,6 +146,7 @@ async def downgrade(ctx: Context):
 
 @cli.command(help="Show current available heads in migrate location.")
 @click.pass_context
+@close_db
 async def heads(ctx: Context):
     app = ctx.obj["app"]
     versions = Migrate.get_all_version_files()
@@ -139,7 +161,8 @@ async def heads(ctx: Context):
 
 @cli.command(help="List all migrate items.")
 @click.pass_context
-def history(ctx):
+@close_db
+async def history(ctx: Context):
     versions = Migrate.get_all_version_files()
     for version in versions:
         click.secho(version, fg=Color.green)
@@ -170,7 +193,7 @@ async def init(
     parser.set(name, "tortoise_orm", tortoise_orm)
     parser.set(name, "location", location)
 
-    with open(config_file, "w") as f:
+    with open(config_file, "w", encoding="utf-8") as f:
         parser.write(f)
 
     if not os.path.isdir(location):
@@ -183,12 +206,13 @@ async def init(
 @cli.command(help="Generate schema and generate app migrate location.")
 @click.option(
     "--safe",
-    is_flag=True,
+    type=bool,
     default=True,
     help="When set to true, creates the table only when it does not already exist.",
     show_default=True,
 )
 @click.pass_context
+@close_db
 async def init_db(ctx: Context, safe):
     config = ctx.obj["config"]
     location = ctx.obj["location"]
@@ -198,6 +222,8 @@ async def init_db(ctx: Context, safe):
     if not os.path.isdir(dirname):
         os.mkdir(dirname)
         click.secho(f"Success create app migrate location {dirname}", fg=Color.green)
+    else:
+        return click.secho(f"Inited {app} already", fg=Color.yellow)
 
     Migrate.write_old_models(config, app, location)
 
@@ -205,6 +231,15 @@ async def init_db(ctx: Context, safe):
     connection = get_app_connection(config, app)
     await generate_schema_for_client(connection, safe)
 
+    schema = get_schema_sql(connection, safe)
+
+    version = await Migrate.generate_version()
+    await Aerich.create(version=version, app=app)
+    with open(os.path.join(dirname, version), "w", encoding="utf-8") as f:
+        content = {
+            "upgrade": [schema],
+        }
+        json.dump(content, f, ensure_ascii=False, indent=2)
     return click.secho(f'Success generate schema for app "{app}"', fg=Color.green)
 
 
