@@ -8,16 +8,17 @@ from tortoise.fields import Field, JSONField, TextField, UUIDField
 class BaseDDL:
     schema_generator_cls: Type[BaseSchemaGenerator] = BaseSchemaGenerator
     DIALECT = "sql"
-    _DROP_TABLE_TEMPLATE = "DROP TABLE IF EXISTS {table_name}"
-    _ADD_COLUMN_TEMPLATE = "ALTER TABLE {table_name} ADD {column}"
-    _DROP_COLUMN_TEMPLATE = "ALTER TABLE {table_name} DROP COLUMN {column_name}"
+    _DROP_TABLE_TEMPLATE = 'DROP TABLE IF EXISTS "{table_name}"'
+    _ADD_COLUMN_TEMPLATE = 'ALTER TABLE "{table_name}" ADD {column}'
+    _DROP_COLUMN_TEMPLATE = 'ALTER TABLE "{table_name}" DROP COLUMN "{column_name}"'
     _ADD_INDEX_TEMPLATE = (
-        "ALTER TABLE {table_name} ADD {unique} INDEX {index_name} ({column_names})"
+        'ALTER TABLE "{table_name}" ADD {unique} INDEX "{index_name}" ({column_names})'
     )
-    _DROP_INDEX_TEMPLATE = "ALTER TABLE {table_name} DROP INDEX {index_name}"
-    _ADD_FK_TEMPLATE = "ALTER TABLE {table_name} ADD CONSTRAINT `{fk_name}` FOREIGN KEY (`{db_column}`) REFERENCES `{table}` (`{field}`) ON DELETE {on_delete}"
-    _DROP_FK_TEMPLATE = "ALTER TABLE {table_name} DROP FOREIGN KEY {fk_name}"
-    _M2M_TABLE_TEMPLATE = "CREATE TABLE {table_name} ({backward_key} {backward_type} NOT NULL REFERENCES {backward_table} ({backward_field}) ON DELETE CASCADE,{forward_key} {forward_type} NOT NULL REFERENCES {forward_table} ({forward_field}) ON DELETE CASCADE){extra}{comment};"
+    _DROP_INDEX_TEMPLATE = 'ALTER TABLE "{table_name}" DROP INDEX "{index_name}"'
+    _ADD_FK_TEMPLATE = 'ALTER TABLE "{table_name}" ADD CONSTRAINT "{fk_name}" FOREIGN KEY ("{db_column}") REFERENCES "{table}" ("{field}") ON DELETE {on_delete}'
+    _DROP_FK_TEMPLATE = 'ALTER TABLE "{table_name}" DROP FOREIGN KEY "{fk_name}"'
+    _M2M_TABLE_TEMPLATE = 'CREATE TABLE "{table_name}" ("{backward_key}" {backward_type} NOT NULL REFERENCES "{backward_table}" ("{backward_field}") ON DELETE CASCADE,"{forward_key}" {forward_type} NOT NULL REFERENCES "{forward_table}" ("{forward_field}") ON DELETE CASCADE){extra}{comment};'
+    _MODIFY_COLUMN_TEMPLATE = 'ALTER TABLE "{table_name}" MODIFY COLUMN {column}'
 
     def __init__(self, client: "BaseDBAsyncClient"):
         self.client = client
@@ -51,7 +52,7 @@ class BaseDDL:
     def drop_m2m(self, field: ManyToManyFieldInstance):
         return self._DROP_TABLE_TEMPLATE.format(table_name=field.through)
 
-    def add_column(self, model: "Type[Model]", field_object: Field):
+    def _get_default(self, model: "Type[Model]", field_object: Field):
         db_table = model._meta.db_table
         default = field_object.default
         db_column = field_object.model_field_name
@@ -74,6 +75,11 @@ class BaseDDL:
                     default = ""
         else:
             default = ""
+        return default
+
+    def add_column(self, model: "Type[Model]", field_object: Field):
+        db_table = model._meta.db_table
+
         return self._ADD_COLUMN_TEMPLATE.format(
             table_name=db_table,
             column=self.schema_generator._create_string(
@@ -89,7 +95,7 @@ class BaseDDL:
                 if field_object.description
                 else "",
                 is_primary_key=field_object.pk,
-                default=default,
+                default=self._get_default(model, field_object),
             ),
         )
 
@@ -98,6 +104,27 @@ class BaseDDL:
             table_name=model._meta.db_table, column_name=column_name
         )
 
+    def modify_column(self, model: "Type[Model]", field_object: Field):
+        db_table = model._meta.db_table
+        return self._MODIFY_COLUMN_TEMPLATE.format(
+            table_name=db_table,
+            column=self.schema_generator._create_string(
+                db_column=field_object.model_field_name,
+                field_type=field_object.get_for_dialect(self.DIALECT, "SQL_TYPE"),
+                nullable="NOT NULL" if not field_object.null else "",
+                unique="",
+                comment=self.schema_generator._column_comment_generator(
+                    table=db_table,
+                    column=field_object.model_field_name,
+                    comment=field_object.description,
+                )
+                if field_object.description
+                else "",
+                is_primary_key=field_object.pk,
+                default=self._get_default(model, field_object),
+            ),
+        )
+
     def add_index(self, model: "Type[Model]", field_names: List[str], unique=False):
         return self._ADD_INDEX_TEMPLATE.format(
             unique="UNIQUE" if unique else "",
@@ -152,3 +179,12 @@ class BaseDDL:
                 to_field=to_field_name,
             ),
         )
+
+    def alter_column_default(self, model: "Type[Model]", field_object: Field):
+        pass
+
+    def alter_column_null(self, model: "Type[Model]", field_object: Field):
+        pass
+
+    def set_comment(self, model: "Type[Model]", field_object: Field):
+        pass
