@@ -3,6 +3,7 @@ import os
 import re
 from copy import deepcopy
 from datetime import datetime
+from importlib import import_module
 from typing import Dict, List, Tuple, Type
 
 from tortoise import (
@@ -16,7 +17,7 @@ from tortoise import (
 from tortoise.fields import Field
 
 from aerich.ddl import BaseDDL
-from aerich.models import Aerich
+from aerich.models import MAX_VERSION_LENGTH, Aerich
 from aerich.utils import get_app_connection
 
 
@@ -27,6 +28,7 @@ class Migrate:
     _downgrade_fk_m2m_index_operators: List[str] = []
     _upgrade_m2m: List[str] = []
     _downgrade_m2m: List[str] = []
+    _aerich = Aerich.__name__
 
     ddl: BaseDDL
     migrate_config: dict
@@ -34,6 +36,7 @@ class Migrate:
     diff_app = "diff_models"
     app: str
     migrate_location: str
+    dialect: str
 
     @classmethod
     def get_old_model_file(cls):
@@ -41,7 +44,10 @@ class Migrate:
 
     @classmethod
     def get_all_version_files(cls) -> List[str]:
-        return sorted(filter(lambda x: x.endswith("json"), os.listdir(cls.migrate_location)))
+        return sorted(
+            filter(lambda x: x.endswith("json"), os.listdir(cls.migrate_location)),
+            key=lambda x: x.split("_")[0],
+        )
 
     @classmethod
     async def get_last_version(cls) -> Aerich:
@@ -58,39 +64,47 @@ class Migrate:
         await Tortoise.init(config=migrate_config)
 
         connection = get_app_connection(config, app)
-        if connection.schema_generator.DIALECT == "mysql":
+        cls.dialect = connection.schema_generator.DIALECT
+        if cls.dialect == "mysql":
             from aerich.ddl.mysql import MysqlDDL
 
             cls.ddl = MysqlDDL(connection)
-        elif connection.schema_generator.DIALECT == "sqlite":
+        elif cls.dialect == "sqlite":
             from aerich.ddl.sqlite import SqliteDDL
 
             cls.ddl = SqliteDDL(connection)
-        elif connection.schema_generator.DIALECT == "postgres":
+        elif cls.dialect == "postgres":
             from aerich.ddl.postgres import PostgresDDL
 
             cls.ddl = PostgresDDL(connection)
-        else:
-            raise NotImplementedError("Current only support MySQL")
 
     @classmethod
     async def _get_last_version_num(cls):
         last_version = await cls.get_last_version()
         if not last_version:
-            return 0
+            return None
         version = last_version.version
-        return version.split("_")[0]
+        return int(version.split("_", 1)[0])
+
+    @classmethod
+    async def generate_version(cls, name=None):
+        now = datetime.now().strftime("%Y%M%D%H%M%S").replace("/", "")
+        last_version_num = await cls._get_last_version_num()
+        if last_version_num is None:
+            return f"0_{now}_init.json"
+        version = f"{last_version_num + 1}_{now}_{name}.json"
+        if len(version) > MAX_VERSION_LENGTH:
+            raise ValueError(f"Version name exceeds maximum length ({MAX_VERSION_LENGTH})")
+        return version
 
     @classmethod
     async def _generate_diff_sql(cls, name):
-        now = datetime.now().strftime("%Y%M%D%H%M%S").replace("/", "")
-        last_version_num = await cls._get_last_version_num()
-        version = f"{last_version_num + 1}_{now}_{name}.json"
+        version = await cls.generate_version(name)
         content = {
             "upgrade": cls.upgrade_operators,
             "downgrade": cls.downgrade_operators,
         }
-        with open(os.path.join(cls.migrate_location, version), "w") as f:
+        with open(os.path.join(cls.migrate_location, version), "w", encoding="utf-8") as f:
             json.dump(content, f, indent=2, ensure_ascii=False)
         return version
 
@@ -105,8 +119,8 @@ class Migrate:
         diff_models = apps.get(cls.diff_app)
         app_models = apps.get(cls.app)
 
-        cls._diff_models(diff_models, app_models)
-        cls._diff_models(app_models, diff_models, False)
+        cls.diff_models(diff_models, app_models)
+        cls.diff_models(app_models, diff_models, False)
 
         cls._merge_operators()
 
@@ -148,11 +162,11 @@ class Migrate:
         """
         pattern = rf"(\n)?('|\")({app})(.\w+)('|\")"
         for i, model_file in enumerate(model_files):
-            with open(model_file, "r") as f:
+            with open(model_file, "r", encoding="utf-8") as f:
                 content = f.read()
             ret = re.sub(pattern, rf"\2{cls.diff_app}\4\5", content)
             mode = "w" if i == 0 else "a"
-            with open(old_model_file, mode) as f:
+            with open(old_model_file, mode, encoding="utf-8") as f:
                 f.write(ret)
 
     @classmethod
@@ -166,8 +180,11 @@ class Migrate:
         """
         temp_config = deepcopy(config)
         path = os.path.join(location, app, cls.old_models)
-        path = path.replace("/", ".").lstrip(".")
-        temp_config["apps"][cls.diff_app] = {"models": [path]}
+        path = path.replace(os.sep, ".").lstrip(".")
+        temp_config["apps"][cls.diff_app] = {
+            "models": [path],
+            "default_connection": config.get("apps").get(app).get("default_connection", "default"),
+        }
         return temp_config
 
     @classmethod
@@ -179,15 +196,17 @@ class Migrate:
         :param location:
         :return:
         """
+        cls.app = app
+
         old_model_files = []
         models = config.get("apps").get(app).get("models")
         for model in models:
-            old_model_files.append(model.replace(".", "/") + ".py")
+            old_model_files.append(import_module(model).__file__)
 
         cls.cp_models(app, old_model_files, os.path.join(location, app, cls.get_old_model_file()))
 
     @classmethod
-    def _diff_models(
+    def diff_models(
         cls, old_models: Dict[str, Type[Model]], new_models: Dict[str, Type[Model]], upgrade=True
     ):
         """
@@ -197,6 +216,9 @@ class Migrate:
         :param upgrade:
         :return:
         """
+        old_models.pop(cls._aerich, None)
+        new_models.pop(cls._aerich, None)
+
         for new_model_str, new_model in new_models.items():
             if new_model_str not in old_models.keys():
                 cls._add_operator(cls.add_model(new_model), upgrade)
@@ -207,6 +229,10 @@ class Migrate:
             if old_model not in new_models.keys():
                 cls._add_operator(cls.remove_model(old_models.get(old_model)), upgrade)
 
+    @classmethod
+    def _is_fk_m2m(cls, field: Field):
+        return isinstance(field, (ForeignKeyFieldInstance, ManyToManyFieldInstance))
+
     @classmethod
     def add_model(cls, model: Type[Model]):
         return cls.ddl.create_table(model)
@@ -247,6 +273,27 @@ class Migrate:
                 )
             else:
                 old_field = old_fields_map.get(new_key)
+                new_field_dict = new_field.describe(serializable=True)
+                new_field_dict.pop("unique")
+                new_field_dict.pop("indexed")
+                old_field_dict = old_field.describe(serializable=True)
+                old_field_dict.pop("unique")
+                old_field_dict.pop("indexed")
+                if not cls._is_fk_m2m(new_field) and new_field_dict != old_field_dict:
+                    if cls.dialect == "postgres":
+                        if new_field.null != old_field.null:
+                            cls._add_operator(
+                                cls._alter_null(new_model, new_field), upgrade=upgrade
+                            )
+                        if new_field.default != old_field.default:
+                            cls._add_operator(
+                                cls._alter_default(new_model, new_field), upgrade=upgrade
+                            )
+                        if new_field.description != old_field.description:
+                            cls._add_operator(
+                                cls._set_comment(new_model, new_field), upgrade=upgrade
+                            )
+                    cls._add_operator(cls._modify_field(new_model, new_field), upgrade=upgrade)
                 if (old_field.index and not new_field.index) or (
                     old_field.unique and not new_field.unique
                 ):
@@ -255,7 +302,7 @@ class Migrate:
                             old_model, (old_field.model_field_name,), old_field.unique
                         ),
                         upgrade,
-                        isinstance(old_field, (ForeignKeyFieldInstance, ManyToManyFieldInstance)),
+                        cls._is_fk_m2m(old_field),
                     )
                 elif (new_field.index and not old_field.index) or (
                     new_field.unique and not old_field.unique
@@ -263,16 +310,14 @@ class Migrate:
                     cls._add_operator(
                         cls._add_index(new_model, (new_field.model_field_name,), new_field.unique),
                         upgrade,
-                        isinstance(new_field, (ForeignKeyFieldInstance, ManyToManyFieldInstance)),
+                        cls._is_fk_m2m(new_field),
                     )
 
         for old_key in old_keys:
             field = old_fields_map.get(old_key)
             if old_key not in new_keys and not cls._exclude_field(field, upgrade):
                 cls._add_operator(
-                    cls._remove_field(old_model, field),
-                    upgrade,
-                    isinstance(field, (ForeignKeyFieldInstance, ManyToManyFieldInstance)),
+                    cls._remove_field(old_model, field), upgrade, cls._is_fk_m2m(field),
                 )
 
         for new_index in new_indexes:
@@ -341,6 +386,22 @@ class Migrate:
             return cls.ddl.create_m2m_table(model, field)
         return cls.ddl.add_column(model, field)
 
+    @classmethod
+    def _alter_default(cls, model: Type[Model], field: Field):
+        return cls.ddl.alter_column_default(model, field)
+
+    @classmethod
+    def _alter_null(cls, model: Type[Model], field: Field):
+        return cls.ddl.alter_column_null(model, field)
+
+    @classmethod
+    def _set_comment(cls, model: Type[Model], field: Field):
+        return cls.ddl.set_comment(model, field)
+
+    @classmethod
+    def _modify_field(cls, model: Type[Model], field: Field):
+        return cls.ddl.modify_column(model, field)
+
     @classmethod
     def _remove_field(cls, model: Type[Model], field: Field):
         if isinstance(field, ForeignKeyFieldInstance):
